@@ -125,7 +125,7 @@ class Embedding(keras.layers.Embedding):
     def compute_mask(self, inputs, mask=None):
         """为了适配T5，保证第一个token不被mask
         """
-        if self._current_mode == 'embedding':
+        if K.ndim(inputs) == 2:
             mask = super(Embedding, self).compute_mask(inputs, mask)
             if mask is not None:
                 mask1 = K.ones_like(mask[:, :1], dtype='bool')
@@ -138,7 +138,6 @@ class Embedding(keras.layers.Embedding):
         """新增mode参数，可以为embedding或dense。如果为embedding，
         则等价于普通Embedding层；如果为dense，则等价于无bias的Dense层。
         """
-        self._current_mode = mode
         if mode == 'embedding':
             return super(Embedding, self).call(inputs)
         else:
@@ -146,7 +145,11 @@ class Embedding(keras.layers.Embedding):
             return K.dot(inputs, kernel)
 
     def compute_output_shape(self, input_shape):
-        if self._current_mode == 'embedding':
+        """关于判据，本来是通过缓存call时的mode参数来判断的，但是后来发现
+        Keras在使用compute_output_shape的时候不一定配套调用了call函数，
+        所以缓存的mode可能是不准的，因此只能出此下策。
+        """
+        if len(input_shape) == 2:
             return super(Embedding, self).compute_output_shape(input_shape)
         else:
             return input_shape[:2] + (K.int_shape(self.embeddings)[0],)
@@ -279,8 +282,8 @@ class MultiHeadAttention(Layer):
 
     def pay_attention_to(self, inputs, mask=None, **kwargs):
         """实现标准的乘性多头注意力
-        a_mask: 对attention矩阵的mask。
-                不同的attention mask对应不同的应用。
+        a_bias: 对attention矩阵的bias。
+                不同的attention bias对应不同的应用。
         p_bias: 在attention里的位置偏置。
                 一般用来指定相对位置编码的种类。
         说明: 这里单独分离出pay_attention_to函数，是为了方便
@@ -289,30 +292,30 @@ class MultiHeadAttention(Layer):
         """
         (qw, kw, vw), n = inputs[:3], 3
         q_mask, v_mask = mask
-        a_mask, p_bias = kwargs.get('a_mask'), kwargs.get('p_bias')
-        if a_mask:
-            a_mask = inputs[n]
+        a_bias, p_bias = kwargs.get('a_bias'), kwargs.get('p_bias')
+        if a_bias:
+            a_bias = inputs[n]
             n += 1
         # Attention
         a = tf.einsum('bjhd,bkhd->bhjk', qw, kw)
         # 处理位置编码
         if p_bias == 'typical_relative':
-            pos_embeddings = inputs[n]
-            a = a + tf.einsum('bjhd,jkd->bhjk', qw, pos_embeddings)
+            position_bias = inputs[n]
+            a = a + tf.einsum('bjhd,jkd->bhjk', qw, position_bias)
         elif p_bias == 't5_relative':
-            pos_embeddings = K.permute_dimensions(inputs[n], (2, 0, 1))
-            a = a + K.expand_dims(pos_embeddings, 0)
+            position_bias = K.permute_dimensions(inputs[n], (2, 0, 1))
+            a = a + K.expand_dims(position_bias, 0)
         # Attention（续）
         if self.attention_scale:
             a = a / self.key_size**0.5
+        if a_bias is not None:
+            a = a + a_bias
         a = sequence_masking(a, v_mask, 1, -1)
-        if a_mask is not None:
-            a = a - (1 - a_mask) * 1e12
         a = K.softmax(a)
         # 完成输出
         o = tf.einsum('bhjk,bkhd->bjhd', a, vw)
         if p_bias == 'typical_relative':
-            o = o + tf.einsum('bhjk,jkd->bjhd', a, pos_embeddings)
+            o = o + tf.einsum('bhjk,jkd->bjhd', a, position_bias)
         return o
 
     def compute_output_shape(self, input_shape):
@@ -495,14 +498,13 @@ class PositionEmbedding(Layer):
     def call(self, inputs):
         """如果custom_position_ids，那么第二个输入为自定义的位置id
         """
-        input_shape = K.shape(inputs)
-        batch_size, seq_len = input_shape[0], input_shape[1]
-
         if self.custom_position_ids:
             inputs, position_ids = inputs
-            if K.dtype(position_ids) != 'int32':
+            if 'int' not in K.dtype(position_ids):
                 position_ids = K.cast(position_ids, 'int32')
         else:
+            input_shape = K.shape(inputs)
+            batch_size, seq_len = input_shape[0], input_shape[1]
             position_ids = K.arange(0, seq_len, dtype='int32')[None]
 
         if self.hierarchical:
@@ -511,21 +513,21 @@ class PositionEmbedding(Layer):
             embeddings = embeddings / (1 - alpha)
             embeddings_x = K.gather(embeddings, position_ids // self.input_dim)
             embeddings_y = K.gather(embeddings, position_ids % self.input_dim)
-            pos_embeddings = alpha * embeddings_x + (1 - alpha) * embeddings_y
+            embeddings = alpha * embeddings_x + (1 - alpha) * embeddings_y
         else:
             if self.custom_position_ids:
-                pos_embeddings = K.gather(self.embeddings, position_ids)
+                embeddings = K.gather(self.embeddings, position_ids)
             else:
-                pos_embeddings = self.embeddings[None, :seq_len]
+                embeddings = self.embeddings[None, :seq_len]
 
         if self.merge_mode == 'add':
-            return inputs + pos_embeddings
+            return inputs + embeddings
         elif self.merge_mode == 'mul':
-            return inputs * pos_embeddings
+            return inputs * embeddings
         else:
             if not self.custom_position_ids:
-                pos_embeddings = K.tile(pos_embeddings, [batch_size, 1, 1])
-            return K.concatenate([inputs, pos_embeddings])
+                embeddings = K.tile(embeddings, [batch_size, 1, 1])
+            return K.concatenate([inputs, embeddings])
 
     def compute_output_shape(self, input_shape):
         if self.custom_position_ids:
@@ -564,33 +566,30 @@ class SinusoidalPositionEmbedding(Layer):
     def call(self, inputs):
         """如果custom_position_ids，那么第二个输入为自定义的位置id
         """
-        input_shape = K.shape(inputs)
-        batch_size, seq_len = input_shape[0], input_shape[1]
-
         if self.custom_position_ids:
+            seq_len = K.shape(inputs)[1]
             inputs, position_ids = inputs
+            if 'float' not in K.dtype(position_ids):
+                position_ids = K.cast(position_ids, K.floatx())
         else:
+            input_shape = K.shape(inputs)
+            batch_size, seq_len = input_shape[0], input_shape[1]
             position_ids = K.arange(0, seq_len, dtype=K.floatx())[None]
 
         indices = K.arange(0, self.output_dim // 2, dtype=K.floatx())
         indices = K.pow(10000.0, -2 * indices / self.output_dim)
-        pos_embeddings = tf.einsum('bn,d->bnd', position_ids, indices)
-        pos_embeddings = K.concatenate([
-            K.sin(pos_embeddings)[..., None],
-            K.cos(pos_embeddings)[..., None]
-        ])
-        pos_embeddings = K.reshape(
-            pos_embeddings, (-1, seq_len, self.output_dim)
-        )
+        embeddings = tf.einsum('bn,d->bnd', position_ids, indices)
+        embeddings = K.stack([K.sin(embeddings), K.cos(embeddings)], axis=-1)
+        embeddings = K.reshape(embeddings, (-1, seq_len, self.output_dim))
 
         if self.merge_mode == 'add':
-            return inputs + pos_embeddings
+            return inputs + embeddings
         elif self.merge_mode == 'mul':
-            return inputs * pos_embeddings
+            return inputs * embeddings
         else:
             if not self.custom_position_ids:
-                pos_embeddings = K.tile(pos_embeddings, [batch_size, 1, 1])
-            return K.concatenate([inputs, pos_embeddings])
+                embeddings = K.tile(embeddings, [batch_size, 1, 1])
+            return K.concatenate([inputs, embeddings])
 
     def compute_output_shape(self, input_shape):
         if self.custom_position_ids:
