@@ -8,6 +8,7 @@ import re
 import sys
 from collections import defaultdict
 import json
+import keras
 
 _open_ = open
 is_py2 = six.PY2
@@ -132,24 +133,40 @@ class open:
 
 
 def parallel_apply(
-    func, iterable, workers, max_queue_size, callback=None, dummy=False
+    func,
+    iterable,
+    workers,
+    max_queue_size,
+    callback=None,
+    dummy=False,
+    random_seeds=True
 ):
     """多进程或多线程地将func应用到iterable的每个元素中。
     注意这个apply是异步且无序的，也就是说依次输入a,b,c，但是
     输出可能是func(c), func(a), func(b)。
     参数：
+        callback: 处理单个输出的回调函数；
         dummy: False是多进程/线性，True则是多线程/线性；
-        callback: 处理单个输出的回调函数。
+        random_seeds: 每个进程的随机种子。
     """
     if dummy:
         from multiprocessing.dummy import Pool, Queue
     else:
         from multiprocessing import Pool, Queue
 
-    in_queue, out_queue = Queue(max_queue_size), Queue()
+    in_queue, out_queue, seed_queue = Queue(max_queue_size), Queue(), Queue()
+    if random_seeds is True:
+        random_seeds = np.random.randint(0, 2**32, workers)
+    elif random_seeds is None or random_seeds is False:
+        random_seeds = []
+    for seed in random_seeds:
+        seed_queue.put(seed)
 
     def worker_step(in_queue, out_queue):
-        # 单步函数包装成循环执行
+        """单步函数包装成循环执行
+        """
+        if not seed_queue.empty():
+            np.random.seed(seed_queue.get())
         while True:
             i, d = in_queue.get()
             r = func(d)
@@ -196,7 +213,7 @@ def parallel_apply(
         return [r[1] for r in results]
 
 
-def sequence_padding(inputs, length=None, padding=0):
+def sequence_padding(inputs, length=None, padding=0, mode='post'):
     """Numpy函数，将序列padding到同一长度
     """
     if length is None:
@@ -206,7 +223,12 @@ def sequence_padding(inputs, length=None, padding=0):
     outputs = []
     for x in inputs:
         x = x[:length]
-        pad_width[0] = (0, length - len(x))
+        if mode == 'post':
+            pad_width[0] = (0, length - len(x))
+        elif mode == 'pre':
+            pad_width[0] = (length - len(x), 0)
+        else:
+            raise ValueError('"mode" argument must be "post" or "pre".')
         x = np.pad(x, pad_width, 'constant', constant_values=padding)
         outputs.append(x)
 
@@ -359,11 +381,12 @@ class AutoRegressiveDecoder(object):
     """通用自回归生成模型解码基类
     包含beam search和random sample两种策略
     """
-    def __init__(self, start_id, end_id, maxlen, minlen=None):
+    def __init__(self, start_id, end_id, maxlen, minlen=1):
         self.start_id = start_id
         self.end_id = end_id
         self.maxlen = maxlen
-        self.minlen = minlen or 1
+        self.minlen = minlen
+        self.models = {}
         if start_id is None:
             self.first_output_ids = np.empty((1, 0), dtype=int)
         else:
@@ -409,6 +432,18 @@ class AutoRegressiveDecoder(object):
 
         return actual_decorator
 
+    def last_token(self, model):
+        """创建一个只返回最后一个token输出的新Model
+        """
+        if model not in self.models:
+            outputs = [
+                keras.layers.Lambda(lambda x: x[:, -1])(output)
+                for output in model.outputs
+            ]
+            self.models[model] = keras.models.Model(model.inputs, outputs)
+
+        return self.models[model]
+
     def predict(self, inputs, output_ids, states=None):
         """用户需自定义递归预测函数
         说明：定义的时候，需要用wraps方法进行装饰，传入default_rtype和use_states，
